==> style-o-matic-1.1.5.tgz: package/es/components/ToolBar/ToolBarText.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, setCorePropDefaults, ROLE } from "../../lib";

var ToolBarText = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarText, _CoreComponent);

  function ToolBarText() {
    _classCallCheck(this, ToolBarText);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBarText.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      children
    );
  };

  return ToolBarText;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TEXT,
  text: ""
}), _temp);


export default ToolBarText;

==> style-o-matic-1.1.37.tgz: package/es/components/ToolBar/ToolBarText.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, getCorePropDefaults, ROLE } from "../../lib";

var ToolBarText = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarText, _CoreComponent);

  function ToolBarText() {
    _classCallCheck(this, ToolBarText);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBarText.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      children
    );
  };

  return ToolBarText;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TEXT,
  text: ""
}), _temp);


export default ToolBarText;
